@@ -130,7 +130,7 @@ void EncodingPlugin::enableControls()
     comboInput->setEnabled( !checkInput->isChecked() );
     comboOutput->setEnabled( !checkOutput->isChecked() );
 
-    updatePreview();
+    //updatePreview();
 }
 
 void EncodingPlugin::setLocale( KComboBox* combo )
