@@ -23,13 +23,21 @@
 
 #include <kapplication.h>
 #include <kconfig.h>
+#include <klocale.h>
 
+#include <qpopupmenu.h>
 #include <qtimer.h>
 
 #define TIMER_DELAY 500
 
-KMyHistoryCombo::KMyHistoryCombo(QWidget* parent, const char* name)
-    :KHistoryCombo(parent, name)
+#define KRENAME_FILENAME       5000
+#define KRENAME_FILENAME_LOWER 5001
+#define KRENAME_FILENAME_UPPER 5002
+#define KRENAME_NUMBER         5003
+#define KRENAME_DATE           5004
+
+KMyHistoryCombo::KMyHistoryCombo( bool customPopup, QWidget* parent, const char* name)
+    : KHistoryCombo(parent, name)
 {
     QStringList history;
     QStringList completion;
@@ -49,6 +57,9 @@ KMyHistoryCombo::KMyHistoryCombo(QWidget* parent, const char* name)
                         
     connect( this, SIGNAL( textChanged( const QString & ) ), this, SLOT( textChangedGovernor() ) );
     connect( m_timer, SIGNAL( timeout() ), this, SIGNAL( delayedTextChanged() ) );
+
+    if( customPopup )
+        connect( this, SIGNAL( aboutToShowContextMenu( QPopupMenu* ) ), this, SLOT( slotCustomContextMenu( QPopupMenu* ) ) );
 }
 
 KMyHistoryCombo::~KMyHistoryCombo()
@@ -107,3 +118,50 @@ void KMyHistoryCombo::textChangedGovernor()
     m_timer->stop();
     m_timer->start( TIMER_DELAY, true );
 }
+
+void KMyHistoryCombo::slotCustomContextMenu( QPopupMenu* p )
+{
+    QPopupMenu* krename = new QPopupMenu( p );
+    krename->insertItem( i18n("&Filename"), KRENAME_FILENAME );
+    krename->insertItem( i18n("Filename to &lowercase"), KRENAME_FILENAME_LOWER );
+    krename->insertItem( i18n("Filename to &uppercase"), KRENAME_FILENAME_UPPER );
+    krename->insertItem( i18n("&Number"), KRENAME_NUMBER );
+    krename->insertItem( i18n("&Date"), KRENAME_DATE );
+
+    connect( krename, SIGNAL( activated( int ) ), this, SLOT( slotInsertKRenameCommand( int ) ) );
+
+    p->insertSeparator( 0 );
+    p->insertItem( i18n("Insert &KRename token"), krename, 0, 0 );
+}
+
+void KMyHistoryCombo::slotInsertKRenameCommand( int id )
+{
+    QString t;
+
+    // TODO:
+    // also use constants for KRename tokens!
+
+    switch( id )
+    {
+        case KRENAME_FILENAME:
+            t = "$";
+            break;
+        case KRENAME_FILENAME_LOWER:
+            t = "%";
+            break;
+        case KRENAME_FILENAME_UPPER:
+            t = "&";
+            break;
+        case KRENAME_NUMBER:
+            t = "#";
+            break;
+        case KRENAME_DATE:
+            t = "[date]";
+            break;
+        default:
+            break;
+    }
+
+    if( !t.isEmpty() )
+        this->lineEdit()->insert( t );
+}
