@@ -31,6 +31,7 @@
 #include <kio/previewjob.h>
 #include <kio/netaccess.h>
 #include <qptrlist.h>
+#include <kurldrag.h>
 #include <kurllabel.h>
 #include <kpixmap.h>
 #include <kpixmapeffect.h> 
@@ -123,7 +124,7 @@ bool KMyListBox::isFile( const KURL & f, bool autoadd )
 
     if( file.isDir() ) {
         if( autoadd )
-            addDir( f, "*", false, false );
+            addDir( f, "*", false, true );
         return false;
     }
 
@@ -173,8 +174,8 @@ void KMyListBox::dropEvent(QDropEvent* e)
     if( e->source() != this )
         e->accept(QTextDrag::canDecode(e));
 
-    QStringList list;
-    if ( QUriDrag::decodeLocalFiles(e, list) )
+    KURL::List list;
+    if( KURLDrag::decode( e, list ) )
     {
         
         KApplication::setOverrideCursor( Qt::waitCursor );
@@ -182,13 +183,7 @@ void KMyListBox::dropEvent(QDropEvent* e)
         setUpdatesEnabled( false );
 
         for( unsigned int i = 0; i < list.count(); i++ )
-        {
-            KURL url;
-            // we have to use setPath here instead of the constructor so
-            // that everything is escaped correctly (e.g. a # in a filename)
-            url.setPath( list[i] );
-            addFile( url, false );
-        }
+            addFile( list[i], false );
         
         setUpdatesEnabled( true );
         listerDone( NULL );
@@ -487,8 +482,8 @@ bool KMyListBox::isInList( KURL text )
 {
     // TODO: faster find algorithm
     for( unsigned int i = 0; i < count(); i++ ) {
-        KMyListBoxItem* it = static_cast<KMyListBoxItem*>(item( i ) );
-        if( it->url() == text ) {
+        KMyListBoxItem* it = dynamic_cast<KMyListBoxItem*>(item( i ) );
+        if( it && it->url() == text ) {
             return true;
         }
     }
@@ -716,8 +711,7 @@ void KMyListBox::positionLabel()
 {
     if( count() )
     {
-        if( label->isVisible() )
-            label->hide();
+        label->hide();
     }
     else
     {
