@@ -600,6 +600,7 @@ void KRenameImpl::setupFileTab1()
     help.append( "\\\\;;" + i18n("Insert '\\\\'") );
     help.append( "\\[;;" + i18n("Insert '['") );
     help.append( "\\];;" + i18n("Insert ']'") );
+    help.append( "\\#;;" + i18n("Insert '#'") );
     helpDialogData->add( i18n("Special Characters:" ), &help, SmallIcon("krename") );
 
     /*
@@ -899,7 +900,7 @@ void KRenameImpl::setupTab1()
 
             (*it)->check = new QCheckBox( i18n("&Use this plugin"), parent );
             connect( (*it)->check, SIGNAL( clicked() ), this, SLOT( pluginHelpChanged() ) );
-            connect( (*it)->plugin, SIGNAL( previewChanged() ), this, SLOT( updatePreview() ) );
+            connect( (*it)->plugin, SIGNAL( previewChanged( Plugin* ) ), this, SLOT( updatePluginPreview( Plugin* ) ) );
             Layout->addWidget( (*it)->check );
             (*it)->plugin->drawInterface( g, gLayout );
 
@@ -1014,8 +1015,6 @@ void KRenameImpl::start()
     config->setGroup("FileExtension");
     config->writeEntry("FileExtensionCombo", comboExtension->currentItem() );
 
-    config->sync();
-
     // save the configuration
     saveConfig();
 
@@ -1210,6 +1209,19 @@ int KRenameImpl::currentRenameMode()
     return RENAME;
 }
 
+void KRenameImpl::updatePluginPreview( Plugin* p ) 
+{
+    QPtrListIterator<PluginLoader::PluginLibrary> it( plugin->libs ); // iterator for dict
+    while ( it.current() ) {
+        if( (*it)->plugin == p && (*it)->usePlugin ) {
+            updatePreview();
+            return;
+        }
+
+        ++it;
+    }
+}
+
 void KRenameImpl::updatePreview()
 {
     // is there a number in the filename or extension
