@@ -40,21 +40,18 @@ wizard::wizard( KRenameImpl* impl, QRect r, QWidget* parent,  const char* name )
     setIcon( BarIcon( "krename" ) );
     menuBar = new KMenuBar(this);
 
-    if( impl ) {
-        krename = impl;
-        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
+    krename = impl ? impl : new KRenameImpl( this, menuBar, this->finishButton() );
 
-        krename->changeParent( this, menuBar, this->finishButton(), r );
-        krename->setWizardMode( true );
-    } else {
-        krename = new KRenameImpl( this, menuBar, this->finishButton() );
-        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
-
-        krename->setup( true );
-    }
-    
+    connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
     connect( krename, SIGNAL( showPage( int ) ), this, SLOT( slotShowPage( int ) ) );
     connect( krename, SIGNAL( enableFinish( bool ) ), this, SLOT( slotEnableFinish( bool ) ) );
+
+    if( impl )
+    {
+        krename->changeParent( this, menuBar, this->finishButton(), r );
+        krename->setWizardMode( true );
+    } else
+        krename->setup( true );
     
     // Tell KStartupInfo that KRename has been loaded completly
     KStartupInfoId id;
